@@ -8,7 +8,7 @@ use POSIX qw/ceil floor/;
 use Scalar::Util qw/blessed looks_like_number/;
 require Exporter;
 
-our $VERSION = '0.016';
+our $VERSION = '0.017';
 our @ISA = 'Exporter';
 our @EXPORT_OK = 'calc';
 our $ERROR;
@@ -78,6 +78,7 @@ use constant ROUND_HALF => 0.50000000000008;
 		'%'   => { args => 2, code => sub { _real($_[0]) % _real($_[1]) } },
 		'^'   => { args => 2, code => sub { $_[0] ** $_[1] } },
 		'!'   => { args => 1, code => sub { die "Factorial of negative number" if _real($_[0]) < 0;
+		                                    die "Factorial of infinity" if _real($_[0]) == 'inf';
 		                                    reduce { $a * $b } 1, 1.._real($_[0]) } },
 		'u-'  => { args => 1, code => sub { -$_[0] } },
 		'u+'  => { args => 1, code => sub { +$_[0] } },
@@ -362,6 +363,8 @@ sub try_evaluate {
 	return $result;
 }
 
+1;
+
 =encoding utf8
 
 =head1 NAME
@@ -423,9 +426,10 @@ customized using L</"add_functions"> and L</"remove_functions">.
   my $result = calc '2+2';
   
   $ perl -MMath::Calc::Parser=calc -E 'say calc "2+2"'
+  $ perl -Math -e '2+2'
 
 Compact exportable function wrapping L</"evaluate"> for string expressions.
-Throws an exception on error.
+Throws an exception on error. See L<ath> for easy compact one-liners.
 
 =head1 ATTRIBUTES
 
@@ -624,7 +628,3 @@ the terms of the Artistic License version 2.0.
 =head1 SEE ALSO
 
 L<Math::Complex>
-
-=cut
-
-1;
